#

    	itinerary

    		[ ] mongo instead of tinydb

    			[ ] two URLs
    				( ) mongo cloud URL
    				( ) local URL

    		[ ] variables

    			( ) from path
    			( ) configurable in memory

    		poetry:
    			Like a fortress or dyson sphere,
    			the paths within the scales start
    			to appear.

    		itinerary, v2:
    			mongo instead of tinydb

    		itinerary, ranked:
    			fractional amounts of essentials

    			supp, fractional amounts of measured ingredients

    			maybe:
    				food, fractional amounts of measured ingredients

    		possibilities:
    			100% organic eco-friendly from sustainable farming.

    			instances:
    				programmatic:
    					import apoplast
    					apoplast_1 = apoplast.instantiate ()

    				click:
    					[xonsh] apoplast instantiate